@@ -83,7 +83,7 @@ def get_idps(base_url,
     """
     idps = requests.get(glue_url(base_url, '/saml', '/idps'),
                         headers={'Accept': 'application/json'},
-                        verify=verify)
+                        verify=verify)  # nosec: B113 (currently not dealing with timeouts)
 
     if idps.status_code == codes.ok:
         return {idp.get('entityID'): idp for idp in idps.json()}
@@ -116,7 +116,7 @@ def probe_openam_idp(idp_url,
     log.info('probing OpenAM login URL {} (realm {})', probe, idp_realm)
     probe = requests.get(probe, params=omit_empty({
         'realm': idp_realm
-    }), allow_redirects=False, verify=verify)
+    }), allow_redirects=False, verify=verify)  # nosec: B113 (currently not dealing with timeouts)
 
     if probe.headers.get('WWW-Authenticate') == 'Negotiate':
         # idp wants us to use Kerberos, construct the info we need
