@@ -358,7 +358,9 @@ def bulk(traces, dest, split=1000, stream='raw', fname=safe_name, write=to_file,
     if jobs is True or not isinstance(jobs, int):
         raise TypeError('an int or False is required for arguments jobs')
 
-    num_total = len(traces)
+    # determine the number of traces, preferring results.num_results over len(results)
+    num_total = getattr(traces, 'num_results', None) or len(traces)
+
     # determine the ideal length of the folder names for split sets
     order = len(str(num_total // split)) if split else 1
 
